
package com.tmerclub.cloud.search.bo;

import com.tmerclub.cloud.common.constant.Constant;
import com.tmerclub.cloud.common.model.BaseModel;
import com.tmerclub.cloud.search.canal.annotation.CanalModel;
import com.tmerclub.cloud.search.canal.common.FieldNamingPolicy;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;

/**
 * sku信息
 *
 * @author tmerclub
 * @date 2020-12-08 15:54:22
 */
@CanalModel(database = "tmerclub" + Constant.UNDERLINE_ENV + "_product", table = "sku", fieldNamingPolicy = FieldNamingPolicy.LOWER_UNDERSCORE)
public class SkuBO extends BaseModel implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;
    /**
     * 属性id
     */
    private Long skuId;

    /**
     * SPU id
     */
    private Long spuId;

    /**
     * 多个销售属性值id逗号分隔
     */
    private String attrs;

    /**
     * sku名称
     */
    private String skuName;

    /**
     * sku图片
     */
    private String imgUrl;

    /**
     * 售价，整数方式保存
     */
    private Long priceFee;

    /**
     * 市场价，整数方式保存
     */
    private Long marketPriceFee;

    /**
     * 积分价格
     */
    private Long scoreFee;

    /**
     * 商品编码
     */
    private String partyCode;

    /**
     * 商品条形码
     */
    private String modelId;

    /**
     * 商品重量
     */
    private BigDecimal weight;

    /**
     * 商品体积
     */
    private BigDecimal volume;

    /**
     * 状态 1:enable, 0:disable, -1:deleted
     */
    private Integer status;

    /**
     * 当商品为代销商品时，供应商商品skuid
     */
    private Long supplierSkuId;

    /**
     * 组合id(组合商品独有)
     */
    private Long skuComboId;

    public Long getSkuComboId() {
        return skuComboId;
    }

    public void setSkuComboId(Long skuComboId) {
        this.skuComboId = skuComboId;
    }

    public String getSkuName() {
        return skuName;
    }

    public void setSkuName(String skuName) {
        this.skuName = skuName;
    }

    public Long getSkuId() {
        return skuId;
    }

    public void setSkuId(Long skuId) {
        this.skuId = skuId;
    }

    public Long getSpuId() {
        return spuId;
    }

    public void setSpuId(Long spuId) {
        this.spuId = spuId;
    }

    public String getAttrs() {
        return attrs;
    }

    public void setAttrs(String attrs) {
        this.attrs = attrs;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public Long getPriceFee() {
        return priceFee;
    }

    public void setPriceFee(Long priceFee) {
        this.priceFee = priceFee;
    }

    public Long getMarketPriceFee() {
        return marketPriceFee;
    }

    public void setMarketPriceFee(Long marketPriceFee) {
        this.marketPriceFee = marketPriceFee;
    }

    public Long getScoreFee() {
        return scoreFee;
    }

    public void setScoreFee(Long scoreFee) {
        this.scoreFee = scoreFee;
    }

    public String getPartyCode() {
        return partyCode;
    }

    public void setPartyCode(String partyCode) {
        this.partyCode = partyCode;
    }

    public String getModelId() {
        return modelId;
    }

    public void setModelId(String modelId) {
        this.modelId = modelId;
    }

    public BigDecimal getWeight() {
        return weight;
    }

    public void setWeight(BigDecimal weight) {
        this.weight = weight;
    }

    public BigDecimal getVolume() {
        return volume;
    }

    public void setVolume(BigDecimal volume) {
        this.volume = volume;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getSupplierSkuId() {
        return supplierSkuId;
    }

    public void setSupplierSkuId(Long supplierSkuId) {
        this.supplierSkuId = supplierSkuId;
    }

    @Override
    public String toString() {
        return "SkuBO{" +
                "skuId=" + skuId +
                ", spuId=" + spuId +
                ", attrs='" + attrs + '\'' +
                ", skuName='" + skuName + '\'' +
                ", imgUrl='" + imgUrl + '\'' +
                ", priceFee=" + priceFee +
                ", marketPriceFee=" + marketPriceFee +
                ", scoreFee=" + scoreFee +
                ", partyCode='" + partyCode + '\'' +
                ", modelId='" + modelId + '\'' +
                ", weight=" + weight +
                ", volume=" + volume +
                ", status=" + status +
                ", supplierSkuId=" + supplierSkuId +
                ", skuComboId=" + skuComboId +
                '}';
    }
}
